/* Create new schema for the synchronization queue */
CREATE TABLE sync_queue_tmp ( id INTEGER PRIMARY KEY,
    uuid TEXT NOT NULL,
    predefined_id INTEGER DEFAULT 0,
    parent TEXT DEFAULT NULL,
    action TEXT NOT NULL,
    timestamp INTEGER DEFAULT NULL,
    UNIQUE(uuid, action)
);

/* Copy data from the old one */
INSERT INTO sync_queue_tmp SELECT * FROM sync_queue;

/* Drop old entity */
DROP TABLE sync_queue;

/* Rename new one */
ALTER TABLE sync_queue_tmp RENAME TO sync_queue;

-- Sync list table timestamp trigger (make sure that timestamp is valid)
CREATE TRIGGER sync_queue_insert_valid_timestamp
AFTER INSERT ON sync_queue
WHEN NEW.timestamp IS NULL OR NEW.timestamp <= 0
BEGIN
    UPDATE sync_queue SET timestamp = strftime('%s','now') WHERE id = NEW.id;
END;

-- Creation sync queue constraint
CREATE TRIGGER sync_queue_insert
BEFORE INSERT ON sync_queue
BEGIN
    -- Ignore silently any data duplication
    SELECT CASE
        WHEN (SELECT count(*) FROM sync_queue WHERE uuid = NEW.uuid AND action = NEW.action > 0)
            THEN RAISE (IGNORE)
    END;
END;
